package pl.edu.pg.eti.kask.rpg.character.controller.api;

import pl.edu.pg.eti.kask.rpg.character.dto.GetCharacterResponse;
import pl.edu.pg.eti.kask.rpg.character.dto.GetCharactersResponse;
import pl.edu.pg.eti.kask.rpg.character.dto.PutCharacterRequest;

import java.util.UUID;

/**
 * Controller for character resource. It does not return or receive entity objects but dto objects which present only
 * those fields which are used in communication with client.
 */
public interface CharacterController {

    /**
     * @return list of characters
     */
    GetCharactersResponse getCharacters();

    /**
     * @param userId characters' owner
     * @return list of characters
     */
    GetCharactersResponse getUserCharacters(UUID userId);

    /**
     * @param professionId characters' profession
     * @return list of characters
     */
    GetCharactersResponse getProfessionCharacters(UUID professionId);

    /**
     * @param id character's id
     * @return single character
     */
    GetCharacterResponse getCharacter(UUID id);

    /**
     * @param userId      owner id
     * @param characterId character id
     * @return single character
     */
    GetCharacterResponse getUserCharacter(UUID userId, UUID characterId);

    /**
     * @param id character's id
     * @return single character's portrait
     */
    byte[] getCharacterPortrait(UUID id);

    /**
     * @param id      character's id
     * @param request new character
     */
    void putCharacter(UUID id, PutCharacterRequest request);

    /**
     * Deletes selected character.
     *
     * @param id character's id
     */
    void deleteCharacter(UUID id);

}
